.. _background_step:

============================
Background Image Subtraction
============================

.. toctree::
   :maxdepth: 2

   description.rst
   arguments.rst
   reference_files.rst

.. automodapi:: jwst.background
